# pyLoDStorage
python List of Dict (Table) Storage library

[![pypi](https://img.shields.io/pypi/pyversions/pyLodStorage)](https://pypi.org/project/pyLodStorage/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyLoDStorage/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/pyLoDStorage/actions/workflows/build.yml)
[![PyPI Status](https://img.shields.io/pypi/v/pyLodStorage.svg)](https://pypi.python.org/pypi/pyLodStorage/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyLoDStorage.svg)](https://github.com/WolfgangFahl/pyLoDStorage/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyLoDStorage.svg)](https://github.com/WolfgangFahl/pyLoDStorage/issues/?q=is%3Aissue+is%3Aclosed)
[![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://WolfgangFahl.github.io/pyLoDStorage/)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyLoDStorage.svg)](https://www.apache.org/licenses/LICENSE-2.0)

What it is
==========
pyLoDStorage allows to store table like data (List of Dicts) via

- Sqlite3
- JSON
- SPARQL

Installation
============
```bash
pip install pylodstorage
```

Get Sources
===========
```bash
git clone https://github.com/WolfgangFahl/pyLoDStorage
cd pyLodStorage
scripts/install
```

Testing
=======
```bash
scripts/test
```

Usage
=====
see [test cases](https://github.com/WolfgangFahl/pyLoDStorage/tree/master/tests)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/PyLoDStorage)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
* [Tim Holzheim](https://www.semantic-mediawiki.org/wiki/Tim_Holzheim)
